@@ -1,4 +1,4 @@
-﻿//
+//
 // Authors:
 //   Ben Motmans  <ben.motmans@gmail.com>
 //
@@ -29,8 +29,8 @@ using System.Collections.Generic;
 using Mono.Addins;
 using MonoDevelop.Database.Sql;
 using MonoDevelop.Core;
-using MonoDevelop.Core.Gui;
 using MonoDevelop.Components;
+using MonoDevelop.Ide;
 using MonoDevelop.Ide.Gui;
 
 namespace MonoDevelop.Database.Components
@@ -85,7 +85,7 @@ namespace MonoDevelop.Database.Components
 				} catch {}
 			}
 			
-			image.Pixbuf =ImageService.GetPixbuf ("gtk-missing-image", IconSize.Dialog);
+			image.Pixbuf = ImageService.GetIcon ("gtk-missing-image", IconSize.Dialog).ToPixbuf ();
 		}
 	}
 }
