@@ -146,7 +146,7 @@ namespace MonoDevelop.Database.Sql.Npgsql
 								}
 								r.Close ();
 							}
-					} catch (NpgsqlException ex) {
+					} catch (NpgsqlException) {
 						// Don't raise error, if the table doesn't exists return an empty collection
 					} catch (Exception e) {
 						QueryService.RaiseException (e);
@@ -611,7 +611,7 @@ namespace MonoDevelop.Database.Sql.Npgsql
 							}
 							r.Close ();
 						}
-					} catch (Exception e) {
+					} catch (Exception) {
 						// Don't raise error, if the table doesn't exists return an empty collection
 					} finally {
 						conn.Release ();
@@ -1137,7 +1137,7 @@ namespace MonoDevelop.Database.Sql.Npgsql
 				case "bigserial":
 					dts.LengthRange = new Range (length);
 					dts.DataTypeCategory = DataTypeCategory.Integer;
-				break;
+					break;
 				case "numeric":
 				case "decimal":
 				case "real":
@@ -1147,7 +1147,6 @@ namespace MonoDevelop.Database.Sql.Npgsql
 					dts.ScaleRange = new Range (scale);
 					dts.DataTypeCategory = DataTypeCategory.Float;
 					break;
-				break;
 				case "character varying":
 				case "varying":
 				case "varchar":
