@@ -79,7 +79,19 @@ namespace MonoDevelop.Database.Sql.Sqlite
 		
 		public bool ShowCreateDatabaseDialog (IDbFactory factory)
 		{
-			return RunDialog (new SqliteCreateDatabaseDialog (factory));
+			SqliteCreateDatabaseDialog dialog = new SqliteCreateDatabaseDialog (factory);
+			int resp;
+			do {
+				resp = dialog.Run ();
+			} while (resp != (int)ResponseType.Cancel && 
+				    	     resp != (int)ResponseType.Ok && 
+				    		resp != (int)ResponseType.DeleteEvent);
+			dialog.Destroy ();
+			if (resp == (int)ResponseType.Ok)
+				return true;
+			else
+				return false;
+
 		}
 		
 		public bool ShowAddConnectionDialog (IDbFactory factory)
@@ -87,14 +99,25 @@ namespace MonoDevelop.Database.Sql.Sqlite
 			return RunDialog (new SqliteDatabaseConnectionSettingsDialog (factory));
 		}
 		
-		public bool ShowEditConnectionDialog (IDbFactory factory, DatabaseConnectionSettings settings)
+		public bool ShowEditConnectionDialog (IDbFactory factory, 
+		                                      DatabaseConnectionSettings settings, 
+		                                      out DatabaseConnectionSettings newSettings)
 		{
-			return RunDialog (new SqliteDatabaseConnectionSettingsDialog (factory, settings));
+			
+			SqliteDatabaseConnectionSettingsDialog dlg = new  SqliteDatabaseConnectionSettingsDialog(factory, settings);
+			bool result = RunDialog (dlg);
+			if (result)
+				newSettings = dlg.ConnectionSettings;
+			else
+				newSettings = null;			
+			return result;
 		}
 
 		public bool ShowTableEditorDialog (IEditSchemaProvider schemaProvider, TableSchema table, bool create)
 		{
 			TableEditorSettings settings = new TableEditorSettings ();
+			// SQLite doesn't support "NO ACTION" on "Foreign Key"
+			settings.ConstraintSettings.ForeignKeySettings.SupportsNoAction = false;
 			TableEditorDialog dlg = new TableEditorDialog (schemaProvider, create, settings);
 			dlg.Initialize (table);
 
@@ -127,9 +150,18 @@ namespace MonoDevelop.Database.Sql.Sqlite
 		private bool RunDialog (Dialog dlg)
 		{
 			bool result = false;
-			try {	
-				if (dlg.Run () == (int)ResponseType.Ok)
+			// If the Preview Dialog is canceled, don't execute and don't close the Editor Dialog.
+			try {
+				int resp;
+					do {
+						resp = dlg.Run ();
+				         } while (resp != (int)ResponseType.Cancel && resp != (int)ResponseType.Ok && 
+				         resp != (int)ResponseType.DeleteEvent);
+					
+				if (resp == (int)ResponseType.Ok)
 					result = true;
+				else
+					result = false;
 			} finally {
 				dlg.Destroy ();
 			}
